Installation guide
==================

You will find here all the information needed to install the package.

(Don't worry, it shouldn't take long.)

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation/venv
   installation/pypi
   installation/editable
